@@ -402,7 +402,7 @@ class DebugExceptionsTest < ActionDispatch::IntegrationTest
       "action_dispatch.parameter_filter" => [:foo] }
     assert_response 500
 
-    assert_match(CGI.escape_html({ "foo" => "[FILTERED]" }.inspect[1..-2]), body)
+    assert_match(ERB::Util.html_escape({ "foo" => "[FILTERED]" }.inspect[1..-2]), body)
   end
 
   test "show registered original exception if the last exception is TemplateError" do
@@ -466,7 +466,7 @@ class DebugExceptionsTest < ActionDispatch::IntegrationTest
     })
     assert_response 500
 
-    assert_includes(body, CGI.escapeHTML(PP.pp(params, +"", 200)))
+    assert_includes(body, ERB::Util.html_escape(PP.pp(params, +"", 200)))
   end
 
   test "sets the HTTP charset parameter" do
@@ -866,6 +866,16 @@ class DebugExceptionsTest < ActionDispatch::IntegrationTest
     end
   end
 
+  test "shows the link to edit the file in the editor" do
+    @app = DevelopmentApp
+    ActiveSupport::Editor.stub(:current, ActiveSupport::Editor.find("atom")) do
+      get "/actionable_error"
+
+      assert_select "code a.edit-icon"
+      assert_includes body, "atom://core/open"
+    end
+  end
+
   test "shows a buttons for every action in an actionable error" do
     @app = DevelopmentApp
     Rails.stub :root, Pathname.new(".") do
@@ -914,4 +924,37 @@ class DebugExceptionsTest < ActionDispatch::IntegrationTest
     assert_select "#container p", /Showing #{__FILE__} where line #\d+ raised/
     assert_select "#container code", /undefined local variable or method ['`]string”'/
   end
+
+  test "includes copy button in error pages" do
+    @app = DevelopmentApp
+
+    get "/", headers: { "action_dispatch.show_exceptions" => :all }
+    assert_response 500
+
+    assert_match %r{<button onclick="copyAsText\.bind\(this\)\(\)">Copy as text</button>}, body
+    assert_match %r{<script type="text/plain" id="exception-message-for-copy">.*RuntimeError \(puke}m, body
+  end
+
+  test "copy button not shown for XHR requests" do
+    @app = DevelopmentApp
+
+    get "/", headers: {
+      "action_dispatch.show_exceptions" => :all,
+      "HTTP_X_REQUESTED_WITH" => "XMLHttpRequest"
+    }
+
+    assert_response 500
+    assert_no_match %r{<button}, body
+    assert_no_match %r{<script}, body
+  end
+
+  test "exception message includes causes for nested exceptions" do
+    @app = DevelopmentApp
+
+    get "/nested_exceptions", headers: { "action_dispatch.show_exceptions" => :all }
+
+    script_content = body[%r{<script type="text/plain" id="exception-message-for-copy">(.*?)</script>}m, 1]
+    assert_match %r{Third error}, script_content
+    assert_match %r{Caused by:.*Second error}m, script_content
+  end
 end
