@@ -26,7 +26,7 @@ class QueuingTest < ActiveSupport::TestCase
     result = HelloJob.set(wait_until: 1.second.ago).perform_later "Jamie"
     assert result
   rescue NotImplementedError
-    skip
+    pass
   end
 
   test "job returned by enqueue has the arguments available" do
@@ -38,7 +38,7 @@ class QueuingTest < ActiveSupport::TestCase
     job = HelloJob.set(wait_until: Time.utc(2014, 1, 1)).perform_later
     assert_equal Time.utc(2014, 1, 1), job.scheduled_at
   rescue NotImplementedError
-    skip
+    pass
   end
 
   test "job is yielded to block after enqueue with successfully_enqueued property set" do
@@ -50,6 +50,15 @@ class QueuingTest < ActiveSupport::TestCase
     end
   end
 
+  test "configured job is yielded to block after enqueue with successfully_enqueued property set" do
+    HelloJob.set(queue: :some_queue).perform_later "John" do |job|
+      assert_equal "John says hello", JobBuffer.last_value
+      assert_equal [ "John" ], job.arguments
+      assert_equal "some_queue", job.queue_name
+      assert_equal true, job.successfully_enqueued?
+    end
+  end
+
   test "when enqueuing raises an EnqueueError job is yielded to block with error set on job" do
     EnqueueErrorJob.perform_later do |job|
       assert_equal false, job.successfully_enqueued?
@@ -82,26 +91,16 @@ class QueuingTest < ActiveSupport::TestCase
     ActiveJob.perform_all_later(scheduled_job_1, scheduled_job_2)
     assert_equal ["Scheduled 2014 says hello", "Scheduled 2015 says hello"], JobBuffer.values.sort
   rescue NotImplementedError
-    skip
+    pass
   end
 
   test "perform_all_later instrumentation" do
     jobs = HelloJob.new("Jamie"), HelloJob.new("John")
-    called = false
 
-    subscriber = lambda do |*args|
-      called = true
-      event = ActiveSupport::Notifications::Event.new(*args)
-      payload = event.payload
-      assert payload[:adapter]
-      assert_equal jobs, payload[:jobs]
-      assert_equal 2, payload[:enqueued_count]
-    end
-
-    ActiveSupport::Notifications.subscribed(subscriber, "enqueue_all.active_job") do
+    notification = assert_notification("enqueue_all.active_job", jobs:, enqueued_count: 2) do
       ActiveJob.perform_all_later(jobs)
     end
 
-    assert called
+    assert notification.payload[:adapter]
   end
 end
