@@ -252,7 +252,7 @@ module ActiveModel
 
     def init_attributes(other) # :nodoc:
       attrs = super
-      if other.persisted? && self.class.respond_to?(:_default_attributes)
+      if self.class.respond_to?(:_default_attributes)
         self.class._default_attributes.map do |attr|
           attr.with_value_from_user(attrs.fetch_value(attr.name))
         end
