@@ -15,6 +15,12 @@ module ActiveRecord
       class DualEncoding < ActiveRecord::Base
       end
 
+      class SQLiteExtensionSpec
+        def self.to_path
+          "/path/to/sqlite3_extension"
+        end
+      end
+
       def setup
         @conn = SQLite3Adapter.new(
           database: ":memory:",
@@ -630,7 +636,7 @@ module ActiveRecord
           column = @conn.columns("ex").find { |x|
             x.name == "number"
           }
-          assert_equal "10", column.default
+          assert_equal 10, column.default
         end
       end
 
@@ -1071,7 +1077,7 @@ module ActiveRecord
         end
       end
 
-      def test_mixed_case_integer_colum_returns_true_for_rowid
+      def test_mixed_case_integer_column_returns_true_for_rowid
         with_example_table "id_mixed_case InTeGeR PRIMARY KEY" do
           assert @conn.columns("ex").index_by(&:name)["id_mixed_case"].rowid
         end
@@ -1215,6 +1221,30 @@ module ActiveRecord
         conn.disconnect! if conn
       end
 
+      def test_sqlite_extensions_are_constantized_for_the_client_constructor
+        mock_adapter = Class.new(SQLite3Adapter) do
+          class << self
+            attr_reader :new_client_arg
+
+            def new_client(config)
+              @new_client_arg = config
+            end
+          end
+        end
+
+        conn = mock_adapter.new({
+          database: ":memory:",
+          adapter: "sqlite3",
+          extensions: [
+            "/string/literal/path",
+            "ActiveRecord::ConnectionAdapters::SQLite3AdapterTest::SQLiteExtensionSpec",
+          ]
+        })
+        conn.send(:connect)
+
+        assert_equal(["/string/literal/path", SQLiteExtensionSpec], conn.class.new_client_arg[:extensions])
+      end
+
       private
         def assert_logged(logs)
           subscriber = SQLSubscriber.new
