@@ -29,6 +29,26 @@ module ActiveRecord
         def discarded?
           @discarded
         end
+
+        def prepopulate
+        end
+
+        def preconnect
+        end
+
+        def keep_alive
+        end
+
+        def retire_old_connections
+        end
+
+        def maintainable?
+          !discarded? && !flushed && !reaped
+        end
+
+        def reaper_lock
+          yield
+        end
       end
 
       # A reaper with nil time should never reap connections
@@ -118,8 +138,10 @@ module ActiveRecord
         pool = ConnectionPool.new(pool_config)
 
         pool.discard!
-        pool.reap
-        pool.flush
+        assert_nothing_raised do
+          pool.reap
+          pool.flush
+        end
       end
 
       if Process.respond_to?(:fork)
@@ -128,13 +150,20 @@ module ActiveRecord
           pool = ConnectionPool.new(pool_config)
           pool.checkout
 
+          # We currently have a bug somewhere which leads for this test case to be deadlocked
+          # and timeout after 30 minutes on the CI. Until that bug is fixed, this test is made
+          # to timeout after a short period of time to reduce the damage.
+          reader, writer = IO.pipe
+
           pid = fork do
+            reader.close
             pool = ConnectionPool.new(pool_config)
 
             conn, child = new_conn_in_thread(pool)
             child.terminate
 
             wait_for_conn_idle(conn)
+            writer.close
             if conn.in_use?
               exit!(1)
             else
@@ -142,8 +171,14 @@ module ActiveRecord
             end
           end
 
-          Process.waitpid(pid)
-          assert $?.success?
+          writer.close
+          completed = reader.wait_readable(20)
+          reader.close
+          unless completed
+            Process.kill("ABRT", pid)
+          end
+          _, status = Process.wait2(pid)
+          assert_predicate status, :success?
         ensure
           pool.discard!
         end
