@@ -14,13 +14,13 @@ class Car < ActiveRecord::Base
 
   has_one :bulb
 
-  has_many :tyres, counter_cache: :custom_tyres_count
+  has_many :tires, counter_cache: :custom_tires_count
   has_many :engines, dependent: :destroy, inverse_of: :my_car
   has_many :wheels, as: :wheelable, dependent: :destroy
 
   has_many :price_estimates, as: :estimate_of
 
-  scope :incl_tyres, -> { includes(:tyres) }
+  scope :incl_tires, -> { includes(:tires) }
   scope :incl_engines, -> { includes(:engines) }
 
   scope :order_using_new_style,  -> { order("name asc") }
