@@ -22,12 +22,7 @@ require "active_support"
 Thread.abort_on_exception = true
 
 # Show backtraces for deprecated behavior for quicker cleanup.
-ActiveSupport.deprecator.debug = true
-
-# Default to Ruby 2.4+ to_time behavior but allow running tests with old behavior
-ActiveSupport.deprecator.silence do
-  ActiveSupport.to_time_preserves_timezone = ENV.fetch("PRESERVE_TIMEZONES", "1") == "1"
-end
+ActiveSupport.deprecator.behavior = :raise
 
 ActiveSupport::Cache.format_version = 7.1
 
