@@ -8,6 +8,7 @@ require_relative "../constantize_test_cases"
 
 require "active_support/inflector"
 require "active_support/core_ext/string"
+require "active_support/core_ext/object/json"
 require "active_support/time"
 require "active_support/core_ext/string/output_safety"
 require "active_support/core_ext/string/indent"
@@ -610,17 +611,10 @@ class StringConversionsTest < ActiveSupport::TestCase
 
   def test_string_to_time_utc_offset
     with_env_tz "US/Eastern" do
-      if ActiveSupport.to_time_preserves_timezone
-        assert_equal 0, "2005-02-27 23:50".to_time(:utc).utc_offset
-        assert_equal(-18000, "2005-02-27 23:50".to_time.utc_offset)
-        assert_equal 0, "2005-02-27 22:50 -0100".to_time(:utc).utc_offset
-        assert_equal(-3600, "2005-02-27 22:50 -0100".to_time.utc_offset)
-      else
-        assert_equal 0, "2005-02-27 23:50".to_time(:utc).utc_offset
-        assert_equal(-18000, "2005-02-27 23:50".to_time.utc_offset)
-        assert_equal 0, "2005-02-27 22:50 -0100".to_time(:utc).utc_offset
-        assert_equal(-18000, "2005-02-27 22:50 -0100".to_time.utc_offset)
-      end
+      assert_equal 0, "2005-02-27 23:50".to_time(:utc).utc_offset
+      assert_equal(-18000, "2005-02-27 23:50".to_time.utc_offset)
+      assert_equal 0, "2005-02-27 22:50 -0100".to_time(:utc).utc_offset
+      assert_equal(-3600, "2005-02-27 22:50 -0100".to_time.utc_offset)
     end
   end
 
@@ -801,7 +795,9 @@ class CoreExtStringMultibyteTest < ActiveSupport::TestCase
   end
 
   def test_mb_chars_returns_instance_of_proxy_class
-    assert_kind_of ActiveSupport::Multibyte.proxy_class, UTF8_STRING.mb_chars
+    assert_deprecated ActiveSupport.deprecator do
+      assert_kind_of ActiveSupport::Multibyte.proxy_class, UTF8_STRING.mb_chars
+    end
   end
 end
 
@@ -1083,18 +1079,22 @@ class OutputSafetyTest < ActiveSupport::TestCase
     assert_not_predicate string.to_param, :html_safe?
   end
 
+  test "as_json returns a normal string" do
+    string = @string.html_safe
+    assert_not_predicate string.as_json, :html_safe?
+  end
+
+  test "as_json accepts options" do
+    hash = { string: @string.html_safe }
+    assert_not_predicate hash.as_json(only: :string).fetch("string"), :html_safe?
+  end
+
   test "ERB::Util.html_escape should escape unsafe characters" do
     string = '<>&"\''
     expected = "&lt;&gt;&amp;&quot;&#39;"
     assert_equal expected, ERB::Util.html_escape(string)
   end
 
-  test "ERB::Util.html_escape should correctly handle invalid UTF-8 strings" do
-    string = "\251 <"
-    expected = "© &lt;"
-    assert_equal expected, ERB::Util.html_escape(string)
-  end
-
   test "ERB::Util.html_escape should not escape safe strings" do
     string = "<b>hello</b>".html_safe
     assert_equal string, ERB::Util.html_escape(string)
@@ -1108,12 +1108,6 @@ class OutputSafetyTest < ActiveSupport::TestCase
     assert_equal escaped_string, ERB::Util.html_escape_once(escaped_string)
   end
 
-  test "ERB::Util.html_escape_once should correctly handle invalid UTF-8 strings" do
-    string = "\251 <"
-    expected = "© &lt;"
-    assert_equal expected, ERB::Util.html_escape_once(string)
-  end
-
   test "ERB::Util.xml_name_escape should escape unsafe characters for XML names" do
     unsafe_char = ">"
     safe_char = "Á"
