@@ -5,8 +5,6 @@ require "bundler/inline"
 gemfile(true) do
   source "https://rubygems.org"
 
-  git_source(:github) { |repo| "https://github.com/#{repo}.git" }
-
   gem "rails"
   # If you want to test against edge Rails replace the previous line with this:
   # gem "rails", github: "rails/rails", branch: "main"
@@ -16,9 +14,9 @@ require "active_support"
 require "active_support/core_ext/object/blank"
 require "minitest/autorun"
 
-class BugTest < Minitest::Test
+class BugTest < ActiveSupport::TestCase
   def test_stuff
     assert "zomg".present?
-    refute "".present?
+    assert_not "".present?
   end
 end
