@@ -188,7 +188,9 @@ module ApplicationTests
       end
 
       quietly do
-        Rails::Command.invoke(:generate, ["check_argv", "expected"]) # should not raise
+        assert_nothing_raised do
+          Rails::Command.invoke(:generate, ["check_argv", "expected"]) # should not raise
+        end
       end
     end
 
@@ -203,6 +205,15 @@ module ApplicationTests
       end
     end
 
+    test "help hides test_unit when using another test_framework" do
+      add_to_config <<-RUBY
+        config.generators.test_framework :rspec
+      RUBY
+
+      output = rails("generate", "--help")
+      assert_no_match "test_unit", output
+    end
+
     test "skip collision check" do
       rails("generate", "model", "post", "title:string")
 
@@ -240,7 +251,6 @@ module ApplicationTests
             app/views/posts/_form.html.erb
             app/views/posts/_post.html.erb
             test/controllers/posts_controller_test.rb
-            test/system/posts_test.rb
             app/helpers/posts_helper.rb
           )
           assert_equal expected, files
@@ -255,5 +265,26 @@ module ApplicationTests
 
       assert_match(/# Add comment to model/, File.read(model_file))
     end
+
+    if RUBY_VERSION < "3.4" # Revisit when 3.4 is added to the matrix
+      test "generators with apply_rubocop_autocorrect_after_generate!" do
+        with_config do |c|
+          c.generators.apply_rubocop_autocorrect_after_generate!
+        end
+
+        output = rails("generate", "model", "post", "title:string", "body:string")
+        assert_no_match(/3 files inspected, no offenses detected/, output)
+      end
+
+      test "generators with apply_rubocop_autocorrect_after_generate! and pretend" do
+        with_config do |c|
+          c.generators.apply_rubocop_autocorrect_after_generate!
+        end
+
+        assert_nothing_raised do
+          rails("generate", "model", "post", "title:string", "body:string", "--pretend")
+        end
+      end
+    end
   end
 end
